Credits
=======

``nipper`` is written and maintained by `Colin Hemmings <https://colin.hemmings@dataloop.io/>`_.

The development is kindly supported by `Dataloop.IO <https://www.dataloop.io/>`_.

A full list of contributors can be found in `GitHub's overview <https://github.com/dataloop/nipper/graphs/contributors>`_.
